@@ -1,6 +1,9 @@
 use strict;
 use warnings;
-package Module::Faker::Heavy 0.023;
+package Module::Faker::Heavy;
+{
+  $Module::Faker::Heavy::VERSION = '0.016';
+}
 # ABSTRACT: where the fake sausage gets made
 
 use Carp ();
@@ -48,31 +51,17 @@ sub _render {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Module::Faker::Heavy - where the fake sausage gets made
 
 =head1 VERSION
 
-version 0.023
-
-=head1 PERL VERSION
-
-This module should work on any version of perl still receiving updates from
-the Perl 5 Porters.  This means it should work on any version of perl released
-in the last two to three years.  (That is, if the most recently released
-version is v5.40, then this module should work on both v5.40 and v5.38.)
-
-Although it may work on older versions of perl, no guarantee is made that the
-minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+version 0.016
 
 =head1 AUTHOR
 
-Ricardo Signes <cpan@semiotic.systems>
+Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
